﻿using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using GenericParsing;
/*Add this line to use PowerPointWriter*/
using SoftArtisans.OfficeWriter.PowerPointWriter;

namespace EmployeeTraining.templates
{
    public partial class Part1 : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {

        }

        protected void RunReport_Click(object sender, EventArgs e)
        {
            try
            {
                //Instantiate the PowerPointTemplate object
                using (PowerPointTemplate pptt = new PowerPointTemplate())
                {

                    //Open the template file
                    pptt.Open(Page.MapPath("//templates//part1_template.pptx"));

                    //Create a DataBindingProperties object for binding data to the template
                    DataBindingProperties dataProps = pptt.CreateDataBindingProperties();

                    //Create the 'Company' data source
                    //When working with arrays, the values and column names are placed in separate arrays.

                    //The column names are the same as the data markers
                    string[] columnNamesArray = {"Logo"};


                    //Create a byte array to hold the company logo
                    //PowerPointWriter requires the image to be in a byte array
                    //We can use the File.REadAllBytes method to convert the image file to a byte array.
                    Byte[] logoArray = System.IO.File.ReadAllBytes((Page.MapPath("//data//logo.png")));

                    //Set the values for the Company data source
                    object[] valuesArray = {logoArray};

                    //bind the data source to the presentation
                    pptt.BindData(valuesArray, columnNamesArray, "Company", dataProps);

                    //Create the 'Employee' data source, containing the Employee's name and team
                    string[] employeeColNames = {"Name", "Team"};
                    object[] employeeValues = {"Amy Alberts", "Development"};

                    //Bind the Employee data to the presentation
                    pptt.BindData(employeeValues, employeeColNames, "Employee", dataProps);

                    //Create the 'Team' data source
                    //The data for the 'Team' data source is contained in a CSV file. 
                    //We are using a 3rd party parser and a method we defined to create a datatable from the CSV file.
                    DataTable teamData = GetCSVData((Page.MapPath("//data//Team.csv")));

                    //Bind the Team data to the presentation
                    pptt.BindData(teamData, "Team", dataProps);

                    //Process is where the data is imported into the file
                    pptt.Process();

                    //Stream the output in the response as an attachment
                    pptt.Save(Page.Response, "Part1_Output.pptx", false);
                }
            }
            catch (Exception ex)
            {
                ErrorLabel.Visible = true;
                if (ex.Message.Contains("General license key exception"))
                {
                    ErrorLabel.Text = "OfficeWriter does not appear to be" +
                       " installed on this machine. If you have not " +
                       "purchased OfficeWriter, you can download the " +
                       "evaluation version here: " +
                       "http://www.officewriter.com/officewriter-free-evaluation.aspx";
                }
                else
                {
                    ErrorLabel.Text = ex.Message;
                }

            }

        }

        #region Utility Methods
        //Uses CSV reader
        DataTable GetCSVData(string csvFileName)
        {
            DataTable dt;
            using (GenericParserAdapter parser = new GenericParserAdapter(csvFileName))
            {
                parser.ColumnDelimiter = ',';
                parser.FirstRowHasHeader = true;

                dt = parser.GetDataTable();
            }
            return dt;
        }

        #endregion


    }
}
