﻿using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using GenericParsing;
/*Add this line to use PowerPointWriter*/
using SoftArtisans.OfficeWriter.PowerPointWriter;

namespace ProjectProposal
{
    public partial class Part2 : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {

        }

        protected void RunReport_Click(object sender, EventArgs e)
        {
            try
            {

                //------------------------------------------------------------\\
                //This code is from Part 1 - Getting Started with Data Markers of the Project Proposal tutorial.
                //It populates the first two slides of the presentation with data.
                //Instantiate the PowerPointTemplate object
                using (PowerPointTemplate pptt = new PowerPointTemplate())
                {

                    //Open the template file
                    pptt.Open(Page.MapPath("//templates//part2_template.pptx"));

                    //Create a DataBindingProperties object for binding data to the template
                    DataBindingProperties dataProps = pptt.CreateDataBindingProperties();

                    //Create a data set for the header values and column names.
                    //When working with arrays, the values and column names are placed in separate arrays.

                    //This presentation is for a project proposal for a surgery scheduling software
                    object[] valuesArray = {
                                               "Surgery Schedule", "January 1, 2014", "Under Review", "Pamela Blythe",
                                               "January 1, 2015", "6 months",
                                               "Software to schedule surgeries that require multiple resources such as surgeons, assistants, nurses, pre-op and post-op space, surgery theater, long-term recovery rooms."
                                           };

                    //The column names are the same as the data markers
                    string[] columnNamesArray = {
                                                    "Name", "Date", "ReviewStatus", "Leader", "Start", "Estimate",
                                                    "Summary"
                                                };

                    //Use BindData to bind a single row of values to a group of data markers
                    //Make sure the data source name matches the value in the template
                    pptt.BindData(valuesArray, columnNamesArray, "Proposal", dataProps);


                    //-------------------------------------------------------------------------\\
                    //Part 2 - Repeat Behavior and Repeat Slide

                    //Get Team and Cost data
                    //This data is in CSV files, but the data can come from anywhere
                    DataTable dtTeam = GetCSVData(Page.MapPath("//data//Team.csv"));
                    DataTable dtCost = GetCSVData(Page.MapPath("//data//Cost.csv"));

                    //set the MaxRowsPerSlide property
                    dataProps.MaxRowsPerSlide = 10;

                    //Bind the data set for the Team and Cost to the data markers in the template
                    pptt.BindData(dtTeam, "Team", dataProps);
                    pptt.BindData(dtCost, "Cost", dataProps);


                    //Process is where the data is imported into the file
                    pptt.Process();

                    //Stream the output in the response as an attachment
                    pptt.Save(Page.Response, "Part2_Output.pptx", false);

                }
            }
            catch (Exception ex)
            {
                ErrorLabel.Visible = true;
                if (ex.Message.Contains("General license key exception"))
                {
                    ErrorLabel.Text = "OfficeWriter does not appear to be" +
                       " installed on this machine. If you have not " +
                       "purchased OfficeWriter, you can download the " +
                       "evaluation version here: " +
                       "http://www.officewriter.com/officewriter-free-evaluation.aspx";
                }
                else
                {
                    ErrorLabel.Text = ex.Message;
                }

            }
        }
        #region Utility Methods
        //Uses CSV reader
        DataTable GetCSVData(string csvFileName)
        {
            DataTable dt;
            using (GenericParserAdapter parser = new GenericParserAdapter(csvFileName))
            {
                parser.ColumnDelimiter = ',';
                parser.FirstRowHasHeader = true;

                dt = parser.GetDataTable();
            }
            return dt;
        }

        #endregion
      
    }
}
